==> jc-1.4.0.tar.gz: gnu/xml/pipeline/CallFilter__24Requestor.h <==
// final class gnu.xml.pipeline.CallFilter$Requestor

// class file dependencies
// @dep_class 45aa6966e5fee737 gnu_xml_pipeline_CallFilter__24Requestor
// @dep_class d4916ea70623e353 gnu_xml_util_XMLWriter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_util_XMLWriter

#include "gnu/xml/util/XMLWriter.h"

#ifndef _JC_gnu_xml_pipeline_CallFilter__24Requestor_H_
#define _JC_gnu_xml_pipeline_CallFilter__24Requestor_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_CallFilter$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_refs	_jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_refs;
typedef struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_nonrefs	_jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$refs	_jc_gnu_xml_pipeline_CallFilter__24Requestor$refs;
typedef struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$nonrefs	_jc_gnu_xml_pipeline_CallFilter__24Requestor$nonrefs;
typedef struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object	_jc_gnu_xml_pipeline_CallFilter__24Requestor$object;

typedef const struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vmethods	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vmethods;
typedef const struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vtable	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vtable;
typedef const struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vtype	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_CallFilter__24Requestor$method$_init$2ce042b6777dee7b(_jc_env *, struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object *, struct _jc_gnu_xml_pipeline_CallFilter$object *);

// Virtual methods
extern void _jc_gnu_xml_pipeline_CallFilter__24Requestor$method$endDocument$4903a775f2613143(_jc_env *, struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object *);
extern void _jc_gnu_xml_pipeline_CallFilter__24Requestor$method$startDocument$00c72777de6ab226(_jc_env *, struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_CallFilter__24Requestor$method_info$endDocument$4903a775f2613143;
extern _jc_method _jc_gnu_xml_pipeline_CallFilter__24Requestor$method_info$startDocument$00c72777de6ab226;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vmethods {
	void	(*endDocument$4903a775f2613143)(_jc_env *, struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object *);
	void	(*startDocument$00c72777de6ab226)(_jc_env *, struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object *);
};

// Vtable
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_XMLWriter$vmethods	gnu_xml_util_XMLWriter;
	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vmethods	gnu_xml_pipeline_CallFilter__24Requestor;
};

// Vtype
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_refs {
	struct _jc_gnu_xml_pipeline_CallFilter$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$refs {
    _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_refs	gnu_xml_pipeline_CallFilter__24Requestor;
    _jc_gnu_xml_util_XMLWriter$sub_refs	gnu_xml_util_XMLWriter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_XMLWriter$sub_nonrefs	gnu_xml_util_XMLWriter;
    _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_nonrefs	gnu_xml_pipeline_CallFilter__24Requestor;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object {
	_jc_gnu_xml_pipeline_CallFilter__24Requestor$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vtype	*vtype;
	_jc_gnu_xml_pipeline_CallFilter__24Requestor$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_CallFilter__24Requestor$vtype _jc_gnu_xml_pipeline_CallFilter__24Requestor$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_CallFilter__24Requestor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_CallFilter__24Requestor$class_object;

#endif	/* _JC_gnu_xml_pipeline_CallFilter__24Requestor_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/CallFilter__24Requestor.h <==
// final class gnu.xml.pipeline.CallFilter$Requestor

// class file dependencies
// @dep_class 45aa6966e5fee737 gnu_xml_pipeline_CallFilter__24Requestor
// @dep_class d4916ea70623e353 gnu_xml_util_XMLWriter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_util_XMLWriter

#include "gnu/xml/util/XMLWriter.h"

#ifndef _JC_gnu_xml_pipeline_CallFilter__24Requestor_H_
#define _JC_gnu_xml_pipeline_CallFilter__24Requestor_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_CallFilter$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_refs	_jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_refs;
typedef struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_nonrefs	_jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$refs	_jc_gnu_xml_pipeline_CallFilter__24Requestor$refs;
typedef struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$nonrefs	_jc_gnu_xml_pipeline_CallFilter__24Requestor$nonrefs;
typedef struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object	_jc_gnu_xml_pipeline_CallFilter__24Requestor$object;

typedef const struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vmethods	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vmethods;
typedef const struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vtable	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vtable;
typedef const struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vtype	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_CallFilter__24Requestor$method$_init$2ce042b6777dee7b(_jc_env *, struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object *, struct _jc_gnu_xml_pipeline_CallFilter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_pipeline_CallFilter__24Requestor$method$endDocument$4903a775f2613143(_jc_env *, struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_CallFilter__24Requestor$method$startDocument$00c72777de6ab226(_jc_env *, struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_CallFilter__24Requestor$method_info$endDocument$4903a775f2613143;
extern _jc_method _jc_gnu_xml_pipeline_CallFilter__24Requestor$method_info$startDocument$00c72777de6ab226;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vmethods {
	void	(*endDocument$4903a775f2613143)(_jc_env *, struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object *) _JC_JCNI_ATTR;
	void	(*startDocument$00c72777de6ab226)(_jc_env *, struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_XMLWriter$vmethods	gnu_xml_util_XMLWriter;
	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vmethods	gnu_xml_pipeline_CallFilter__24Requestor;
};

// Vtype
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_refs {
	struct _jc_gnu_xml_pipeline_CallFilter$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$refs {
    _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_refs	gnu_xml_pipeline_CallFilter__24Requestor;
    _jc_gnu_xml_util_XMLWriter$sub_refs	gnu_xml_util_XMLWriter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_XMLWriter$sub_nonrefs	gnu_xml_util_XMLWriter;
    _jc_gnu_xml_pipeline_CallFilter__24Requestor$sub_nonrefs	gnu_xml_pipeline_CallFilter__24Requestor;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_CallFilter__24Requestor$object {
	_jc_gnu_xml_pipeline_CallFilter__24Requestor$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_CallFilter__24Requestor$vtype	*vtype;
	_jc_gnu_xml_pipeline_CallFilter__24Requestor$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_CallFilter__24Requestor$vtype _jc_gnu_xml_pipeline_CallFilter__24Requestor$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_CallFilter__24Requestor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_CallFilter__24Requestor$class_object;

#endif	/* _JC_gnu_xml_pipeline_CallFilter__24Requestor_H_ */
